<?php

namespace VaultPHP\SecretEngines\Engines\Secrets;

use VaultPHP\Exceptions\InvalidDataException;
use VaultPHP\Exceptions\InvalidRouteException;
use VaultPHP\Exceptions\VaultAuthenticationException;
use VaultPHP\Exceptions\VaultException;
use VaultPHP\Exceptions\VaultHttpException;
use VaultPHP\Response\BulkEndpointResponse;
use VaultPHP\Response\EndpointResponse;
use VaultPHP\SecretEngines\AbstractSecretEngine;

use VaultPHP\SecretEngines\Engines\Secrets\Request\ReadSecretRequest;
use VaultPHP\SecretEngines\Engines\Secrets\Request\ListSecretsRequest;
use VaultPHP\SecretEngines\Engines\Secrets\Request\CreateOrUpdateSecretRequest;
use VaultPHP\SecretEngines\Engines\Secrets\Request\DeleteSecretRequest;

use VaultPHP\SecretEngines\Engines\Secrets\Response\ReadSecretResponse;
use VaultPHP\SecretEngines\Engines\Secrets\Response\ListSecretsResponse;
use VaultPHP\SecretEngines\Engines\Secrets\Response\CreateOrUpdateSecretResponse;
use VaultPHP\SecretEngines\Engines\Secrets\Response\DeleteSecretResponse;

/**
 * Class Secret
 * @package VaultPHP\SecretEngines\Secrets
 */
final class Secret extends AbstractSecretEngine
{

    /**
     * @param ReadSecretRequest $readSecretRequest
     * @return ReadSecretResponse
     * @throws InvalidDataException
     * @throws InvalidRouteException
     * @throws VaultException
     */
    public function readSecret(ReadSecretRequest $readSecretRequest) 
    {
        return $this->vaultClient->sendApiRequest(
            'GET',
            sprintf('/v1/secret/%s', urlencode($readSecretRequest->getName())),
            ReadSecretResponse::class,
            $readSecretRequest
        );
    }

    /**
     * @param ListSecretsRequest $listSecretsRequest
     * @return ReadSecretResponse
     * @throws InvalidDataException
     * @throws InvalidRouteException
     * @throws VaultException
     */

    public function listSecrets(ListSecretsRequest $listSecretsRequest)
    {
        return $this->vaultClient->sendApiRequest(
            'LIST',
            sprintf('/v1/secret/%s', urlencode($listSecretsRequest->getName())),
            ListSecretsResponse::class,
            $listSecretsRequest
        );
    }

    /**
     * @param CreateOrUpdateSecretRequest $createOrUpdateSecretRequest
     * @return CreateOrUpdateSecretResponse
     * @throws InvalidDataException
     * @throws InvalidRouteException
     * @throws VaultException
     */
    public function CreateOrUpdateSecret (CreateOrUpdateSecretRequest $createOrUpdateSecretRequest) 
    {
        return $this->vaultClient->sendApiRequest(
            'POST',
            sprintf('/v1/secret/%s', urlencode($createOrUpdateSecretRequest->getName())),
            CreateOrUpdateSecretResponse::class,
            $createOrUpdateSecretRequest
        );
    }

    /**
     * @param DeleteSecretRequest $deleteSecretRequest
     * @return DeleteSecretResponse
     * @throws InvalidDataException
     * @throws InvalidRouteException
     * @throws VaultException
     */
    public function DeleteSecret (DeleteSecretRequest $deleteSecretRequest) 
    {
        return $this->vaultClient->sendApiRequest(
            'DELETE',
            sprintf('/v1/secret/%s', urlencode($deleteSecretRequest->getName())),
            DeleteSecretResponse::class,
            $deleteSecretRequest
        );

    }
}
